.. include:: ../../README.rst

This manual documents version |release|.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   parceqt.rst
   document.rst
   treebuilder.rst
   highlighter.rst
   formatter.rst
   util.rst
   treemodel.rst
   debug.rst

.. toctree::
   :hidden:
   :maxdepth: 1
   :caption: Extra links:

   parceqt@Github <https://github.com/wbsoft/parceqt>
   parceqt@PyPi <https://pypi.org/project/parceqt>
   Main parce docs <https://parce.info/>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :doc:`changelog`
* :doc:`license`
